# Copyright 2024 Heinrich Krupp
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
Handler modules for MCP Memory Service.

Extracted from monolithic server_impl.py for better maintainability.
Each module contains related handler functions for specific functionality.
"""

from . import memory, consolidation, utility, documents, quality, graph

__all__ = ['memory', 'consolidation', 'utility', 'documents', 'quality', 'graph']
